summaryrefslogtreecommitdiff
path: root/indra/newview/llfolderviewmodelinventory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llfolderviewmodelinventory.cpp')
-rwxr-xr-xindra/newview/llfolderviewmodelinventory.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/indra/newview/llfolderviewmodelinventory.cpp b/indra/newview/llfolderviewmodelinventory.cpp
index 8c360befc3..44eda4d6c0 100755
--- a/indra/newview/llfolderviewmodelinventory.cpp
+++ b/indra/newview/llfolderviewmodelinventory.cpp
@@ -319,14 +319,14 @@ bool LLInventorySort::operator()(const LLFolderViewModelItemInventory* const& a,
// Equal weight -> use alphabetical order
return (LLStringUtil::compareDict(a->getDisplayName(), b->getDisplayName()) < 0);
}
- else if (weight_a == -1)
+ else if (weight_a == COMPUTE_STOCK_INFINITE)
{
// No weight -> move a at the end of the list
return false;
}
- else if (weight_b == -1)
+ else if (weight_b == COMPUTE_STOCK_INFINITE)
{
// No weight -> move b at the end of the list
return true;
}
else
@@ -319,14 +319,14 @@ bool LLInventorySort::operator()(const LLFolderViewModelItemInventory* const& a,
{
- // No weight -> move a at the end of the list
+ // No stock -> move a at the end of the list
return false;
}
@@ -319,14 +319,14 @@ bool LLInventorySort::operator()(const LLFolderViewModelItemInventory* const& a,
{
- // No weight -> move b at the end of the list
+ // No stock -> move b at the end of the list
return true;
}